==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGroupByExpandStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescriptionMetadata } from "./WebGroupByKeyDescriptionMetadata";
import { WebGroupByExpandStateDescription } from "./WebGroupByExpandStateDescription";
/**
 * @hidden
 */
var WebGroupByExpandStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByExpandStateDescriptionMetadata, _super);
    function WebGroupByExpandStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByExpandStateDescriptionMetadata.b = function (a) {
        if (WebGroupByExpandStateDescriptionMetadata.a == null) {
            WebGroupByExpandStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByExpandStateDescriptionMetadata.c(WebGroupByExpandStateDescriptionMetadata.a);
        }
        if (a.j(WebGroupByExpandStateDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupByExpandStateDescriptionMetadata.a);
        WebGroupByKeyDescriptionMetadata.d(a);
    };
    WebGroupByExpandStateDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByExpandState");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Expanded", "Boolean");
        a.item("Hierarchy", "Array:WebGroupByKeyDescription:GroupByKey");
    };
    WebGroupByExpandStateDescriptionMetadata.d = function (a) {
        WebGroupByExpandStateDescriptionMetadata.b(a);
        a.aa("WebGroupByExpandState", function () { return new WebGroupByExpandStateDescription(); });
        a.z("WebGroupByExpandState", WebGroupByExpandStateDescriptionMetadata.a);
    };
    WebGroupByExpandStateDescriptionMetadata.$t = markType(WebGroupByExpandStateDescriptionMetadata, 'WebGroupByExpandStateDescriptionMetadata');
    WebGroupByExpandStateDescriptionMetadata.a = null;
    return WebGroupByExpandStateDescriptionMetadata;
}(Base));
export { WebGroupByExpandStateDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGroupByExpandStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescriptionMetadata } from "./WebGroupByKeyDescriptionMetadata";
import { WebGroupByExpandStateDescription } from "./WebGroupByExpandStateDescription";
/**
 * @hidden
 */
var WebGroupByExpandStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByExpandStateDescriptionMetadata, _super);
    function WebGroupByExpandStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByExpandStateDescriptionMetadata.b = function (a) {
        if (WebGroupByExpandStateDescriptionMetadata.a == null) {
            WebGroupByExpandStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByExpandStateDescriptionMetadata.c(WebGroupByExpandStateDescriptionMetadata.a);
        }
        if (a.k(WebGroupByExpandStateDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupByExpandStateDescriptionMetadata.a);
        WebGroupByKeyDescriptionMetadata.d(a);
    };
    WebGroupByExpandStateDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByExpandState");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Expanded", "Boolean");
        a.item("Hierarchy", "Array:WebGroupByKeyDescription:GroupByKey");
    };
    WebGroupByExpandStateDescriptionMetadata.d = function (a) {
        WebGroupByExpandStateDescriptionMetadata.b(a);
        a.ac("WebGroupByExpandState", function () { return new WebGroupByExpandStateDescription(); });
        a.ab("WebGroupByExpandState", WebGroupByExpandStateDescriptionMetadata.a);
    };
    WebGroupByExpandStateDescriptionMetadata.$t = markType(WebGroupByExpandStateDescriptionMetadata, 'WebGroupByExpandStateDescriptionMetadata');
    WebGroupByExpandStateDescriptionMetadata.a = null;
    return WebGroupByExpandStateDescriptionMetadata;
}(Base));
export { WebGroupByExpandStateDescriptionMetadata };
